import { Injectable } from '@angular/core';
import { HttpResponse } from '@angular/common/http';
import { Resolve, ActivatedRouteSnapshot, Routes, Router } from '@angular/router';
import { Observable, of, EMPTY } from 'rxjs';
import { flatMap } from 'rxjs/operators';

import { Authority } from 'app/app.constants';
import { UserRouteAccessService } from 'app/core/auth/user-route-access.service';
import { ISavedSearches, SavedSearches } from 'app/shared/model/saved-searches.model';
import { SavedSearchesService } from './saved-searches.service';
import { SavedSearchesComponent } from './saved-searches.component';
import { SavedSearchesDetailComponent } from './saved-searches-detail.component';
import { SavedSearchesUpdateComponent } from './saved-searches-update.component';

@Injectable({ providedIn: 'root' })
export class SavedSearchesResolve implements Resolve<ISavedSearches> {
  constructor(private service: SavedSearchesService, private router: Router) {}

  resolve(route: ActivatedRouteSnapshot): Observable<ISavedSearches> | Observable<never> {
    const id = route.params['id'];
    if (id) {
      return this.service.find(id).pipe(
        flatMap((savedSearches: HttpResponse<SavedSearches>) => {
          if (savedSearches.body) {
            return of(savedSearches.body);
          } else {
            this.router.navigate(['404']);
            return EMPTY;
          }
        })
      );
    }
    return of(new SavedSearches());
  }
}

export const savedSearchesRoute: Routes = [
  {
    path: '',
    component: SavedSearchesComponent,
    data: {
      authorities: [Authority.USER],
      pageTitle: 'gitsearchApp.savedSearches.home.title',
    },
    canActivate: [UserRouteAccessService],
  },
  {
    path: ':id/view',
    component: SavedSearchesDetailComponent,
    resolve: {
      savedSearches: SavedSearchesResolve,
    },
    data: {
      authorities: [Authority.USER],
      pageTitle: 'gitsearchApp.savedSearches.home.title',
    },
    canActivate: [UserRouteAccessService],
  },
  {
    path: 'new',
    component: SavedSearchesUpdateComponent,
    resolve: {
      savedSearches: SavedSearchesResolve,
    },
    data: {
      authorities: [Authority.USER],
      pageTitle: 'gitsearchApp.savedSearches.home.title',
    },
    canActivate: [UserRouteAccessService],
  },
  {
    path: ':id/edit',
    component: SavedSearchesUpdateComponent,
    resolve: {
      savedSearches: SavedSearchesResolve,
    },
    data: {
      authorities: [Authority.USER],
      pageTitle: 'gitsearchApp.savedSearches.home.title',
    },
    canActivate: [UserRouteAccessService],
  },
];
